@@ -1,4 +1,4 @@
-package App::MBUtiny; # $Id: MBUtiny.pm 74 2014-09-22 13:12:37Z abalama $
+package App::MBUtiny; # $Id: MBUtiny.pm 76 2014-09-24 15:02:37Z abalama $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ App::MBUtiny - BackUp system for Your WEBsites
 
 =head1 VERSION
 
-Version 1.08
+Version 1.09
 
 =head1 SYNOPSIS
 
@@ -120,7 +120,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw/ $VERSION /;
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 use CTK::Util;
 use CTK::ConfGenUtil;
@@ -816,7 +816,7 @@ sub backup {
                 $ma{'-message'} .= "\n---\n"
                                  . sprintf("Generated by    : MBUtiny %s\n", $VERSION)
                                  . sprintf("Date generation : %s\n", localtime2date_time())
-                                 . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 74 2014-09-22 13:12:37Z abalama $')
+                                 . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 76 2014-09-24 15:02:37Z abalama $')
                                  . sprintf("Time Stamp      : %s\n", $c->tms())
                                  . sprintf("Configuration   : %s\n", $c->cfgfile);
                 $ma{'-attach'} = _attach($ma{'-attach'}) || [];
@@ -1096,7 +1096,7 @@ sub test {
         $ma{'-message'} .= "\n---\n"
             . sprintf("Generated by    : MBUtiny %s\n", $VERSION)
             . sprintf("Date generation : %s\n", localtime2date_time())
-            . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 74 2014-09-22 13:12:37Z abalama $')
+            . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 76 2014-09-24 15:02:37Z abalama $')
             . sprintf("Time Stamp      : %s\n", $c->tms())
             . sprintf("Configuration   : %s\n", $c->cfgfile);
         $ma{'-attach'} = _attach($ma{'-attach'}) || [];
@@ -1488,6 +1488,7 @@ sub checkup {
     my $status = 1;
     my @saybuffer;
     my @hosts; #    ( )
+    my @req_hosts = split(/\s+/, value($config => 'checkuprequire') || '');
     my %colls; #    (  ) {URL}{AGENT,MESSAGE}
     my $sendreport      = value($config => 'sendreport') || 0;
     my $senderrorreport = value($config => 'senderrorreport') || 0;
@@ -1571,7 +1572,7 @@ sub checkup {
     #  ,  
     my %data;
     my %req_data;
-    foreach (@hosts) {$req_data{$_} = 0};
+    foreach (@hosts, @req_hosts) {$req_data{$_} = 0};
     my @error;
     $c->log_debug("Start processing collectors");
     foreach my $coll_uri (keys %colls) {
@@ -1665,7 +1666,7 @@ sub checkup {
         $ma{'-message'} .= "\n---\n"
             . sprintf("Generated by    : MBUtiny %s\n", $VERSION)
             . sprintf("Date generation : %s\n", localtime2date_time())
-            . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 74 2014-09-22 13:12:37Z abalama $')
+            . sprintf("MBUTiny Id      : %s\n", '$Id: MBUtiny.pm 76 2014-09-24 15:02:37Z abalama $')
             . sprintf("Time Stamp      : %s\n", $c->tms())
             . sprintf("Configuration   : %s\n", $c->cfgfile);
         $ma{'-attach'} = _attach($ma{'-attach'}) || [];
